Class: Google::Cloud::EdgeContainer::V1::Cluster::ConnectionState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/edgecontainer/v1/resources.rb

Overview

ConnectionState holds the current connection state from the cluster to Google.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#state::Google::Cloud::EdgeContainer::V1::Cluster::ConnectionState::State (readonly)

Returns Output only. The current connection state.

Returns:



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 357

class ConnectionState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection state.
  module State
    # Unknown connection state.
    STATE_UNSPECIFIED = 0

    # This cluster is currently disconnected from Google.
    DISCONNECTED = 1

    # This cluster is currently connected to Google.
    CONNECTED = 2

    # This cluster is currently connected to Google, but may have recently
    # reconnected after a disconnection. It is still syncing back.
    CONNECTED_AND_SYNCING = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the connection state was last changed.

Returns:



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 357

class ConnectionState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The connection state.
  module State
    # Unknown connection state.
    STATE_UNSPECIFIED = 0

    # This cluster is currently disconnected from Google.
    DISCONNECTED = 1

    # This cluster is currently connected to Google.
    CONNECTED = 2

    # This cluster is currently connected to Google, but may have recently
    # reconnected after a disconnection. It is still syncing back.
    CONNECTED_AND_SYNCING = 3
  end
end