Class: Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/edgecontainer/v1/resources.rb

Overview

Configuration of the cluster control plane.

Defined Under Namespace

Modules: SharedDeploymentPolicy Classes: Local, Remote

Instance Attribute Summary collapse

Instance Attribute Details

#local::Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::Local

Returns Local control plane configuration.

Warning: Local control plane clusters must be created in their own project. Local control plane clusters cannot coexist in the same project with any other type of clusters, including non-GDCE clusters. Mixing local control plane GDCE clusters with any other type of clusters in the same project can result in data loss.

Note: The following fields are mutually exclusive: local, remote. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::Local)

    Local control plane configuration.

    Warning: Local control plane clusters must be created in their own project. Local control plane clusters cannot coexist in the same project with any other type of clusters, including non-GDCE clusters. Mixing local control plane GDCE clusters with any other type of clusters in the same project can result in data loss.

    Note: The following fields are mutually exclusive: local, remote. If a field in that set is populated, all other fields in the set will automatically be cleared.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 131

class ControlPlane
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration specific to clusters with a control plane hosted remotely.
  class Remote
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration specific to clusters with a control plane hosted locally.
  #
  # Warning: Local control plane clusters must be created in their own
  # project. Local control plane clusters cannot coexist in the same
  # project with any other type of clusters, including non-GDCE clusters.
  # Mixing local control plane GDCE clusters with any other type of
  # clusters in the same project can result in data loss.
  # @!attribute [rw] node_location
  #   @return [::String]
  #     Name of the Google Distributed Cloud Edge zones where this node pool
  #     will be created. For example: `us-central1-edge-customer-a`.
  # @!attribute [rw] node_count
  #   @return [::Integer]
  #     The number of nodes to serve as replicas of the Control Plane.
  # @!attribute [rw] machine_filter
  #   @return [::String]
  #     Only machines matching this filter will be allowed to host control
  #     plane nodes. The filtering language accepts strings like "name=<name>",
  #     and is documented here: [AIP-160](https://google.aip.dev/160).
  # @!attribute [rw] shared_deployment_policy
  #   @return [::Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::SharedDeploymentPolicy]
  #     Policy configuration about how user applications are deployed.
  # @!attribute [rw] control_plane_node_storage_schema
  #   @return [::String]
  #     Optional. Name for the storage schema of control plane nodes.
  #
  #     Warning: Configurable node local storage schema feature is an
  #     experimental feature, and is not recommended for general use
  #     in production clusters/nodepools.
  class Local
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the policy configuration about how user applications are
  # deployed.
  module SharedDeploymentPolicy
    # Unspecified.
    SHARED_DEPLOYMENT_POLICY_UNSPECIFIED = 0

    # User applications can be deployed both on control plane and worker
    # nodes.
    ALLOWED = 1

    # User applications can not be deployed on control plane nodes and can
    # only be deployed on worker nodes.
    DISALLOWED = 2
  end
end

#remote::Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::Remote

Returns Remote control plane configuration.

Note: The following fields are mutually exclusive: remote, local. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 131

class ControlPlane
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration specific to clusters with a control plane hosted remotely.
  class Remote
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration specific to clusters with a control plane hosted locally.
  #
  # Warning: Local control plane clusters must be created in their own
  # project. Local control plane clusters cannot coexist in the same
  # project with any other type of clusters, including non-GDCE clusters.
  # Mixing local control plane GDCE clusters with any other type of
  # clusters in the same project can result in data loss.
  # @!attribute [rw] node_location
  #   @return [::String]
  #     Name of the Google Distributed Cloud Edge zones where this node pool
  #     will be created. For example: `us-central1-edge-customer-a`.
  # @!attribute [rw] node_count
  #   @return [::Integer]
  #     The number of nodes to serve as replicas of the Control Plane.
  # @!attribute [rw] machine_filter
  #   @return [::String]
  #     Only machines matching this filter will be allowed to host control
  #     plane nodes. The filtering language accepts strings like "name=<name>",
  #     and is documented here: [AIP-160](https://google.aip.dev/160).
  # @!attribute [rw] shared_deployment_policy
  #   @return [::Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::SharedDeploymentPolicy]
  #     Policy configuration about how user applications are deployed.
  # @!attribute [rw] control_plane_node_storage_schema
  #   @return [::String]
  #     Optional. Name for the storage schema of control plane nodes.
  #
  #     Warning: Configurable node local storage schema feature is an
  #     experimental feature, and is not recommended for general use
  #     in production clusters/nodepools.
  class Local
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the policy configuration about how user applications are
  # deployed.
  module SharedDeploymentPolicy
    # Unspecified.
    SHARED_DEPLOYMENT_POLICY_UNSPECIFIED = 0

    # User applications can be deployed both on control plane and worker
    # nodes.
    ALLOWED = 1

    # User applications can not be deployed on control plane nodes and can
    # only be deployed on worker nodes.
    DISALLOWED = 2
  end
end