Class: Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::Local
- Inherits:
-
Object
- Object
- Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::Local
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/edgecontainer/v1/resources.rb
Overview
Configuration specific to clusters with a control plane hosted locally.
Warning: Local control plane clusters must be created in their own project. Local control plane clusters cannot coexist in the same project with any other type of clusters, including non-GDCE clusters. Mixing local control plane GDCE clusters with any other type of clusters in the same project can result in data loss.
Instance Attribute Summary collapse
-
#control_plane_node_storage_schema ⇒ ::String
Optional.
-
#machine_filter ⇒ ::String
Only machines matching this filter will be allowed to host control plane nodes.
-
#node_count ⇒ ::Integer
The number of nodes to serve as replicas of the Control Plane.
-
#node_location ⇒ ::String
Name of the Google Distributed Cloud Edge zones where this node pool will be created.
-
#shared_deployment_policy ⇒ ::Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::SharedDeploymentPolicy
Policy configuration about how user applications are deployed.
Instance Attribute Details
#control_plane_node_storage_schema ⇒ ::String
Returns Optional. Name for the storage schema of control plane nodes.
Warning: Configurable node local storage schema feature is an experimental feature, and is not recommended for general use in production clusters/nodepools.
170 171 172 173 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 170 class Local include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_filter ⇒ ::String
Returns Only machines matching this filter will be allowed to host control
plane nodes. The filtering language accepts strings like "name=
170 171 172 173 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 170 class Local include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#node_count ⇒ ::Integer
Returns The number of nodes to serve as replicas of the Control Plane.
170 171 172 173 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 170 class Local include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#node_location ⇒ ::String
Returns Name of the Google Distributed Cloud Edge zones where this node pool
will be created. For example: us-central1-edge-customer-a.
170 171 172 173 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 170 class Local include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#shared_deployment_policy ⇒ ::Google::Cloud::EdgeContainer::V1::Cluster::ControlPlane::SharedDeploymentPolicy
Returns Policy configuration about how user applications are deployed.
170 171 172 173 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 170 class Local include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |