Class: Google::Cloud::EdgeContainer::V1::Cluster::ControlPlaneEncryption
- Inherits:
-
Object
- Object
- Google::Cloud::EdgeContainer::V1::Cluster::ControlPlaneEncryption
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/edgecontainer/v1/resources.rb
Overview
Configuration for Customer-managed KMS key support for control plane nodes.
Instance Attribute Summary collapse
-
#kms_key ⇒ ::String
Optional.
-
#kms_key_active_version ⇒ ::String
readonly
Output only.
-
#kms_key_state ⇒ ::Google::Cloud::EdgeContainer::V1::KmsKeyState
readonly
Output only.
-
#kms_status ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#resource_state ⇒ ::Google::Cloud::EdgeContainer::V1::ResourceState
readonly
Output only.
Instance Attribute Details
#kms_key ⇒ ::String
Returns Optional. The Cloud KMS CryptoKey e.g. projects/{project}/locations/{location}/keyRings/{keyRing}/cryptoKeys/{cryptoKey} to use for protecting control plane disks. If not specified, a Google-managed key will be used instead.
252 253 254 255 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 252 class ControlPlaneEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kms_key_active_version ⇒ ::String (readonly)
Returns Output only. The Cloud KMS CryptoKeyVersion currently in use for protecting control plane disks. Only applicable if kms_key is set.
252 253 254 255 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 252 class ControlPlaneEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kms_key_state ⇒ ::Google::Cloud::EdgeContainer::V1::KmsKeyState (readonly)
Returns Output only. Availability of the Cloud KMS CryptoKey. If not
KEY_AVAILABLE, then nodes may go offline as they cannot access their
local data. This can be caused by a lack of permissions to use the key,
or if the key is disabled or deleted.
252 253 254 255 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 252 class ControlPlaneEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kms_status ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. Error status returned by Cloud KMS when using this key. This
field may be populated only if kms_key_state is not
KMS_KEY_STATE_KEY_AVAILABLE. If populated, this field contains the
error status reported by Cloud KMS.
252 253 254 255 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 252 class ControlPlaneEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_state ⇒ ::Google::Cloud::EdgeContainer::V1::ResourceState (readonly)
Returns Output only. The current resource state associated with the cmek.
252 253 254 255 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 252 class ControlPlaneEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |