Class: Google::Cloud::EdgeContainer::V1::Cluster::MaintenanceEvent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/edgecontainer/v1/resources.rb

Overview

A Maintenance Event is an operation that could cause temporary disruptions to the cluster workloads, including Google-driven or user-initiated cluster upgrades, user-initiated cluster configuration changes that require restarting nodes, etc.

Defined Under Namespace

Modules: Schedule, State, Type

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the maintenance event request was created.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the maintenance event ended, either successfully or not. If the maintenance event is split into multiple maintenance windows, end_time is only updated when the whole flow ends.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time when the maintenance event ended, either successfully or not. If the maintenance event is split into multiple maintenance windows, end_time is only updated when the whole flow ends.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#operation::String (readonly)

Returns Output only. The operation for running the maintenance event. Specified in the format projects//locations//operations/*. If the maintenance event is split into multiple operations (e.g. due to maintenance windows), the latest one is recorded.

Returns:

  • (::String)

    Output only. The operation for running the maintenance event. Specified in the format projects//locations//operations/*. If the maintenance event is split into multiple operations (e.g. due to maintenance windows), the latest one is recorded.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#schedule::Google::Cloud::EdgeContainer::V1::Cluster::MaintenanceEvent::Schedule (readonly)

Returns Output only. The schedule of the maintenance event.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the maintenance event started.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#state::Google::Cloud::EdgeContainer::V1::Cluster::MaintenanceEvent::State (readonly)

Returns Output only. The state of the maintenance event.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#target_version::String (readonly)

Returns Output only. The target version of the cluster.

Returns:

  • (::String)

    Output only. The target version of the cluster.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#type::Google::Cloud::EdgeContainer::V1::Cluster::MaintenanceEvent::Type (readonly)

Returns Output only. The type of the maintenance event.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the maintenance event message was updated.

Returns:



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end

#uuid::String (readonly)

Returns Output only. UUID of the maintenance event.

Returns:

  • (::String)

    Output only. UUID of the maintenance event.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 296

class MaintenanceEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the maintenance event type.
  module Type
    # Unspecified.
    TYPE_UNSPECIFIED = 0

    # Upgrade initiated by users.
    USER_INITIATED_UPGRADE = 1

    # Upgrade driven by Google.
    GOOGLE_DRIVEN_UPGRADE = 2
  end

  # Indicates when the maintenance event should be performed.
  module Schedule
    # Unspecified.
    SCHEDULE_UNSPECIFIED = 0

    # Immediately after receiving the request.
    IMMEDIATELY = 1
  end

  # Indicates the maintenance event state.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # The maintenance event is ongoing. The cluster might be unusable.
    RECONCILING = 1

    # The maintenance event succeeded.
    SUCCEEDED = 2

    # The maintenance event failed.
    FAILED = 3
  end
end