Class: Google::Cloud::EdgeContainer::V1::VpnConnection

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/edgecontainer/v1/resources.rb

Overview

A VPN connection .

Defined Under Namespace

Modules: BgpRoutingMode Classes: Details, LabelsEntry, VpcProject

Instance Attribute Summary collapse

Instance Attribute Details

#bgp_routing_mode::Google::Cloud::EdgeContainer::V1::VpnConnection::BgpRoutingMode

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Dynamic routing mode of the VPC network, regional or global.

Returns:



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#cluster::String

Returns The canonical Cluster name to connect to. It is in the form of projects/{project}/locations/{location}/clusters/{cluster}.

Returns:

  • (::String)

    The canonical Cluster name to connect to. It is in the form of projects/{project}/locations/{location}/clusters/{cluster}.



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the VPN connection was created.

Returns:



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#details::Google::Cloud::EdgeContainer::V1::VpnConnection::Details (readonly)

Returns Output only. The created connection details.

Returns:



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#enable_high_availability::Boolean

Returns Whether this VPN connection has HA enabled on cluster side. If enabled, when creating VPN connection we will attempt to use 2 ANG floating IPs.

Returns:

  • (::Boolean)

    Whether this VPN connection has HA enabled on cluster side. If enabled, when creating VPN connection we will attempt to use 2 ANG floating IPs.



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels associated with this resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels associated with this resource.



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#name::String

Returns Required. The resource name of VPN connection.

Returns:

  • (::String)

    Required. The resource name of VPN connection



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#nat_gateway_ip::String

Returns NAT gateway IP, or WAN IP address. If a customer has multiple NAT IPs, the customer needs to configure NAT such that only one external IP maps to the GMEC Anthos cluster. This is empty if NAT is not used.

Returns:

  • (::String)

    NAT gateway IP, or WAN IP address. If a customer has multiple NAT IPs, the customer needs to configure NAT such that only one external IP maps to the GMEC Anthos cluster. This is empty if NAT is not used.



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#router::String

Returns Optional. The VPN connection Cloud Router name.

Returns:

  • (::String)

    Optional. The VPN connection Cloud Router name.



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the VPN connection was last updated.

Returns:



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#vpc::String

Returns The network ID of VPC to connect to.

Returns:

  • (::String)

    The network ID of VPC to connect to.



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end

#vpc_project::Google::Cloud::EdgeContainer::V1::VpnConnection::VpcProject

Returns Optional. Project detail of the VPC network. Required if VPC is in a different project than the cluster project.

Returns:



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 679

class VpnConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Project detail of the VPC network.
  # @!attribute [rw] project_id
  #   @return [::String]
  #     The project of the VPC to connect to. If not specified, it is the same as
  #     the cluster project.
  # @!attribute [rw] service_account
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::String]
  #     Optional. Deprecated: do not use.
  class VpcProject
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The created connection details.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::State]
  #     The state of this connection.
  # @!attribute [rw] error
  #   @return [::String]
  #     The error message. This is only populated when state=ERROR.
  # @!attribute [rw] cloud_router
  #   @return [::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudRouter]
  #     The Cloud Router info.
  # @!attribute [rw] cloud_vpns
  #   @return [::Array<::Google::Cloud::EdgeContainer::V1::VpnConnection::Details::CloudVpn>]
  #     Each connection has multiple Cloud VPN gateways.
  class Details
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The Cloud Router info.
    # @!attribute [rw] name
    #   @return [::String]
    #     The associated Cloud Router name.
    class CloudRouter
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The Cloud VPN info.
    # @!attribute [rw] gateway
    #   @return [::String]
    #     The created Cloud VPN gateway name.
    class CloudVpn
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The current connection state.
    module State
      # Unknown.
      STATE_UNSPECIFIED = 0

      # Connected.
      STATE_CONNECTED = 1

      # Still connecting.
      STATE_CONNECTING = 2

      # Error occurred.
      STATE_ERROR = 3
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing mode.
  module BgpRoutingMode
    # Unknown.
    BGP_ROUTING_MODE_UNSPECIFIED = 0

    # Regional mode.
    REGIONAL = 1

    # Global mode.
    GLOBAL = 2
  end
end