Class: Google::Cloud::EdgeContainer::V1::VpnConnection::VpcProject

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/edgecontainer/v1/resources.rb

Overview

Project detail of the VPC network.

Instance Attribute Summary collapse

Instance Attribute Details

#project_id::String

Returns The project of the VPC to connect to. If not specified, it is the same as the cluster project.

Returns:

  • (::String)

    The project of the VPC to connect to. If not specified, it is the same as the cluster project.



692
693
694
695
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 692

class VpcProject
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_account::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Deprecated: do not use.

Returns:

  • (::String)

    Optional. Deprecated: do not use.



692
693
694
695
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 692

class VpcProject
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end