Class: Google::Cloud::EdgeContainer::V1::Cluster::SystemAddonsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::EdgeContainer::V1::Cluster::SystemAddonsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/edgecontainer/v1/resources.rb
Overview
Config that customers are allowed to define for GDCE system add-ons.
Defined Under Namespace
Classes: Ingress, VMServiceConfig
Instance Attribute Summary collapse
-
#ingress ⇒ ::Google::Cloud::EdgeContainer::V1::Cluster::SystemAddonsConfig::Ingress
Optional.
-
#vm_service_config ⇒ ::Google::Cloud::EdgeContainer::V1::Cluster::SystemAddonsConfig::VMServiceConfig
Optional.
Instance Attribute Details
#ingress ⇒ ::Google::Cloud::EdgeContainer::V1::Cluster::SystemAddonsConfig::Ingress
Returns Optional. Config for Ingress.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 198 class SystemAddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for the Ingress add-on which allows customers to create an Ingress # object to manage external access to the servers in a cluster. The add-on # consists of istiod and istio-ingress. # @!attribute [rw] disabled # @return [::Boolean] # Optional. Whether Ingress is disabled. # @!attribute [rw] ipv4_vip # @return [::String] # Optional. Ingress VIP. class Ingress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VMServiceConfig defines the configuration for GDCE VM Service. # @!attribute [rw] vmm_enabled # @return [::Boolean] # Optional. Whether VMM is enabled. class VMServiceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#vm_service_config ⇒ ::Google::Cloud::EdgeContainer::V1::Cluster::SystemAddonsConfig::VMServiceConfig
Returns Optional. Config for VM Service.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 198 class SystemAddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for the Ingress add-on which allows customers to create an Ingress # object to manage external access to the servers in a cluster. The add-on # consists of istiod and istio-ingress. # @!attribute [rw] disabled # @return [::Boolean] # Optional. Whether Ingress is disabled. # @!attribute [rw] ipv4_vip # @return [::String] # Optional. Ingress VIP. class Ingress include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VMServiceConfig defines the configuration for GDCE VM Service. # @!attribute [rw] vmm_enabled # @return [::Boolean] # Optional. Whether VMM is enabled. class VMServiceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |