Class: Google::Cloud::EdgeContainer::V1::NodePool
- Inherits:
-
Object
- Object
- Google::Cloud::EdgeContainer::V1::NodePool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/edgecontainer/v1/resources.rb
Overview
A set of Kubernetes nodes in a cluster with common configuration and specification.
Defined Under Namespace
Classes: LabelsEntry, LocalDiskEncryption, NodeConfig
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels associated with this resource.
-
#local_disk_encryption ⇒ ::Google::Cloud::EdgeContainer::V1::NodePool::LocalDiskEncryption
Optional.
-
#machine_filter ⇒ ::String
Only machines matching this filter will be allowed to join the node pool.
-
#name ⇒ ::String
Required.
-
#node_config ⇒ ::Google::Cloud::EdgeContainer::V1::NodePool::NodeConfig
Optional.
-
#node_count ⇒ ::Integer
Required.
-
#node_location ⇒ ::String
Name of the Google Distributed Cloud Edge zone where this node pool will be created.
-
#node_version ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the node pool was created.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels associated with this resource.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#local_disk_encryption ⇒ ::Google::Cloud::EdgeContainer::V1::NodePool::LocalDiskEncryption
Returns Optional. Local disk encryption options. This field is only used when enabling CMEK support.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#machine_filter ⇒ ::String
Returns Only machines matching this filter will be allowed to join the node pool.
The filtering language accepts strings like "name=
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The resource name of the node pool.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#node_config ⇒ ::Google::Cloud::EdgeContainer::V1::NodePool::NodeConfig
Returns Optional. Configuration for each node in the NodePool.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#node_count ⇒ ::Integer
Returns Required. The number of nodes in the pool.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#node_location ⇒ ::String
Returns Name of the Google Distributed Cloud Edge zone where this node pool will be
created. For example: us-central1-edge-customer-a.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#node_version ⇒ ::String (readonly)
Returns Output only. The lowest release version among all worker nodes.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the node pool was last updated.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 518 class NodePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for CMEK support for edge machine local disk encryption. # @!attribute [rw] kms_key # @return [::String] # Optional. The Cloud KMS CryptoKey e.g. # projects/\\{project}/locations/\\{location}/keyRings/\\{keyRing}/cryptoKeys/\\{cryptoKey} # to use for protecting node local disks. If not specified, a # Google-managed key will be used instead. # @!attribute [r] kms_key_active_version # @return [::String] # Output only. The Cloud KMS CryptoKeyVersion currently in use for # protecting node local disks. Only applicable if kms_key is set. # @!attribute [r] kms_key_state # @return [::Google::Cloud::EdgeContainer::V1::KmsKeyState] # Output only. Availability of the Cloud KMS CryptoKey. If not # `KEY_AVAILABLE`, then nodes may go offline as they cannot access their # local data. This can be caused by a lack of permissions to use the key, # or if the key is disabled or deleted. # @!attribute [r] kms_status # @return [::Google::Rpc::Status] # Output only. Error status returned by Cloud KMS when using this key. This # field may be populated only if `kms_key_state` is not # `KMS_KEY_STATE_KEY_AVAILABLE`. If populated, this field contains the # error status reported by Cloud KMS. # @!attribute [r] resource_state # @return [::Google::Cloud::EdgeContainer::V1::ResourceState] # Output only. The current resource state associated with the cmek. class LocalDiskEncryption include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration for each node in the NodePool # @!attribute [rw] labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The Kubernetes node labels # @!attribute [rw] node_storage_schema # @return [::String] # Optional. Name for the storage schema of worker nodes. # # Warning: Configurable node local storage schema feature is an # experimental feature, and is not recommended for general use # in production clusters/nodepools. class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |