Class: Google::Cloud::EdgeContainer::V1::NodePool::NodeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::EdgeContainer::V1::NodePool::NodeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/edgecontainer/v1/resources.rb
Overview
Configuration for each node in the NodePool
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#node_storage_schema ⇒ ::String
Optional.
Instance Attribute Details
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The Kubernetes node labels.
564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 564 class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#node_storage_schema ⇒ ::String
Returns Optional. Name for the storage schema of worker nodes.
Warning: Configurable node local storage schema feature is an experimental feature, and is not recommended for general use in production clusters/nodepools.
564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'proto_docs/google/cloud/edgecontainer/v1/resources.rb', line 564 class NodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |