Class: Google::Cloud::EdgeContainer::V1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::EdgeContainer::V1::OperationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/edgecontainer/v1/service.rb
Overview
Long-running operation metadata for Edge Container API methods.
Defined Under Namespace
Modules: StatusReason
Instance Attribute Summary collapse
-
#api_version ⇒ ::String
API version used to start the operation.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
The time the operation was created.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The time the operation finished running.
-
#requested_cancellation ⇒ ::Boolean
Identifies whether the user has requested cancellation of the operation.
-
#status_message ⇒ ::String
Human-readable status of the operation, if any.
-
#status_reason ⇒ ::Google::Cloud::EdgeContainer::V1::OperationMetadata::StatusReason
Machine-readable status of the operation, if any.
-
#target ⇒ ::String
Server-defined resource path for the target of the operation.
-
#verb ⇒ ::String
The verb executed by the operation.
-
#warnings ⇒ ::Array<::String>
Warnings that do not block the operation, but still hold relevant information for the end user to receive.
Instance Attribute Details
#api_version ⇒ ::String
Returns API version used to start the operation.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the operation was created.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the operation finished running.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#requested_cancellation ⇒ ::Boolean
Returns Identifies whether the user has requested cancellation of the operation.
Operations that have successfully been cancelled have [Operation.error][]
value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#status_message ⇒ ::String
Returns Human-readable status of the operation, if any.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#status_reason ⇒ ::Google::Cloud::EdgeContainer::V1::OperationMetadata::StatusReason
Returns Machine-readable status of the operation, if any.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#target ⇒ ::String
Returns Server-defined resource path for the target of the operation.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#verb ⇒ ::String
Returns The verb executed by the operation.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |
#warnings ⇒ ::Array<::String>
Returns Warnings that do not block the operation, but still hold relevant information for the end user to receive.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'proto_docs/google/cloud/edgecontainer/v1/service.rb', line 56 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the reason for the status of the operation. module StatusReason # Reason unknown. STATUS_REASON_UNSPECIFIED = 0 # The cluster upgrade is currently paused. UPGRADE_PAUSED = 1 end end |